summaryrefslogtreecommitdiffhomepage
path: root/Kernel/KernelKit/ThreadLocalStorage.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'Kernel/KernelKit/ThreadLocalStorage.hxx')
-rw-r--r--Kernel/KernelKit/ThreadLocalStorage.hxx10
1 files changed, 6 insertions, 4 deletions
diff --git a/Kernel/KernelKit/ThreadLocalStorage.hxx b/Kernel/KernelKit/ThreadLocalStorage.hxx
index c6973fd4..a1bc7733 100644
--- a/Kernel/KernelKit/ThreadLocalStorage.hxx
+++ b/Kernel/KernelKit/ThreadLocalStorage.hxx
@@ -24,10 +24,12 @@ struct THREAD_INFORMATION_BLOCK;
struct PACKED THREAD_INFORMATION_BLOCK final
{
Kernel::Char f_Cookie[kTLSCookieLen]; // Process cookie.
- Kernel::UIntPtr f_Code; // Start Address
- Kernel::UIntPtr f_Data; // Allocation Heap
- Kernel::UIntPtr f_BSS; // Stack Pointer.
- Kernel::Int32 f_ID; // Thread execution ID.
+ Kernel::UIntPtr f_Code; // Start address (Instruction Pointer)
+ Kernel::UIntPtr f_Data; // Allocated Heap for process.
+ Kernel::UIntPtr f_Stack; // Application Stack pointer.
+ Kernel::Int32 f_ID; // Thread execution ID.
+ Kernel::Int64 f_UsedHeapPercent; // used heap in percent.
+ Kernel::Int64 f_FreeHeapPercent; // heap free in percent.
};
///! @brief Cookie Sanity check.